@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,10 +25,8 @@
 
 package com.sun.tools.javac.comp;
 
-import com.sun.tools.javac.code.Source.Feature;
 import com.sun.tools.javac.code.Type.UndetVar.UndetVarListener;
 import com.sun.tools.javac.code.Types.TypeMapping;
-import com.sun.tools.javac.comp.Attr.CheckMode;
 import com.sun.tools.javac.resources.CompilerProperties.Fragments;
 import com.sun.tools.javac.resources.CompilerProperties.Notes;
 import com.sun.tools.javac.tree.JCTree;
@@ -59,8 +57,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
-import java.util.HashMap;
-import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.Map;
 import java.util.Optional;
@@ -68,8 +65,10 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.function.BiFunction;
 import java.util.function.BiPredicate;
+import java.util.function.Predicate;
 
 import static com.sun.tools.javac.code.TypeTag.*;
+import java.util.Comparator;
 
 /** Helper class for type parameter inference, used by the attribution phase.
  *
@@ -88,9 +87,6 @@ public class Infer {
     JCDiagnostic.Factory diags;
     Log log;
 
-    /** should the graph solver be used? */
-    boolean allowGraphInference;
-
     /**
      * folder in which the inference dependency graphs should be written.
      */
@@ -118,9 +114,6 @@ public class Infer {
         diags = JCDiagnostic.Factory.instance(context);
         log = Log.instance(context);
         Options options = Options.instance(context);
-        Source source = Source.instance(context);
-        allowGraphInference = Feature.GRAPH_INFERENCE.allowedInSource(source)
-                && options.isUnset("useLegacyInference");
         dependenciesFolder = options.get("debug.dumpInferenceGraphsTo");
         pendingGraphs = List.nil();
 
@@ -137,7 +130,7 @@ public class Infer {
     public static class InferenceException extends InapplicableMethodException {
         private static final long serialVersionUID = 0;
 
-        List<JCDiagnostic> messages = List.nil();
+        transient List<JCDiagnostic> messages = List.nil();
 
         InferenceException() {
             super(null);
@@ -181,11 +174,11 @@ public class Infer {
             resolveContext.methodCheck.argumentsAcceptable(env, deferredAttrContext,   //B2
                     argtypes, mt.getParameterTypes(), warn);
 
-            if (allowGraphInference && resultInfo != null && resultInfo.pt == anyPoly) {
+            if (resultInfo != null && resultInfo.pt == anyPoly) {
                 doIncorporation(inferenceContext, warn);
                 //we are inside method attribution - just return a partially inferred type
                 return new PartiallyInferredMethodType(mt, inferenceContext, env, warn);
-            } else if (allowGraphInference && resultInfo != null) {
+            } else if (resultInfo != null) {
 
                 //inject return constraints earlier
                 doIncorporation(inferenceContext, warn); //propagation
@@ -214,23 +207,9 @@ public class Infer {
             deferredAttrContext.complete();
 
             // minimize as yet undetermined type variables
-            if (allowGraphInference) {
-                inferenceContext.solve(warn);
-            } else {
-                inferenceContext.solveLegacy(true, warn, LegacyInferenceSteps.EQ_LOWER.steps); //minimizeInst
-            }
-
+            inferenceContext.solve(warn);
             mt = (MethodType)inferenceContext.asInstType(mt);
 
-            if (!allowGraphInference &&
-                    inferenceContext.restvars().nonEmpty() &&
-                    resultInfo != null &&
-                    !warn.hasNonSilentLint(Lint.LintCategory.UNCHECKED)) {
-                generateReturnConstraints(env.tree, resultInfo, mt, inferenceContext);
-                inferenceContext.solveLegacy(false, warn, LegacyInferenceSteps.EQ_UPPER.steps); //maximizeInst
-                mt = (MethodType)inferenceContext.asInstType(mt);
-            }
-
             if (resultInfo != null && rs.verboseResolutionMode.contains(VerboseResolutionMode.DEFERRED_INST)) {
                 log.note(env.tree.pos, Notes.DeferredMethodInst(msym, mt, resultInfo.pt));
             }
@@ -238,7 +217,7 @@ public class Infer {
             // return instantiated version of method type
             return mt;
         } finally {
-            if (resultInfo != null || !allowGraphInference) {
+            if (resultInfo != null) {
                 inferenceContext.notifyChange();
             } else {
                 inferenceContext.notifyChange(inferenceContext.boundedVars());
@@ -279,7 +258,7 @@ public class Infer {
         }
 
     /**
-     * A partially infered method/constructor type; such a type can be checked multiple times
+     * A partially inferred method/constructor type; such a type can be checked multiple times
      * against different targets.
      */
     public class PartiallyInferredMethodType extends MethodType {
@@ -306,7 +285,7 @@ public class Infer {
 
         /**
          * Checks this type against a target; this means generating return type constraints, solve
-         * and then roll back the results (to avoid poolluting the context).
+         * and then roll back the results (to avoid polluting the context).
          */
         Type check(Attr.ResultInfo resultInfo) {
             Warner noWarnings = new Warner(null);
@@ -409,21 +388,16 @@ public class Infer {
         } else if (to.hasTag(NONE)) {
             to = from.isPrimitive() ? from : syms.objectType;
         } else if (qtype.hasTag(UNDETVAR)) {
-            if (needsEagerInstantiation((UndetVar)qtype, to, inferenceContext) &&
-                    (allowGraphInference || !to.isPrimitive())) {
+            if (needsEagerInstantiation((UndetVar)qtype, to, inferenceContext)) {
                 to = generateReferenceToTargetConstraint(tree, (UndetVar)qtype, to, resultInfo, inferenceContext);
             }
         } else if (rsInfoInfContext.free(resultInfo.pt)) {
             //propagation - cache captured vars
             qtype = inferenceContext.asUndetVar(rsInfoInfContext.cachedCapture(tree, from, !resultInfo.checkMode.updateTreeType()));
         }
-        Assert.check(allowGraphInference || !rsInfoInfContext.free(to),
-                "legacy inference engine cannot handle constraints on both sides of a subtyping assertion");
         //we need to skip capture?
         Warner retWarn = new Warner();
-        if (!resultInfo.checkContext.compatible(qtype, rsInfoInfContext.asUndetVar(to), retWarn) ||
-                //unchecked conversion is not allowed in source 7 mode
-                (!allowGraphInference && retWarn.hasLint(Lint.LintCategory.UNCHECKED))) {
+        if (!resultInfo.checkContext.compatible(qtype, rsInfoInfContext.asUndetVar(to), retWarn)) {
             throw error(diags.fragment(Fragments.InferNoConformingInstanceExists(inferenceContext.restvars(), mt.getReturnType(), to)));
         }
         return from;
@@ -533,16 +507,18 @@ public class Infer {
             }
         }
         //step 2 - replace fresh tvars in their bounds
-        List<Type> formals = vars;
-        for (Type t : todo) {
+        replaceTypeVarsInBounds(todo.toList(), inferenceContext);
+    }
+
+    private void replaceTypeVarsInBounds(List<Type> vars, InferenceContext inferenceContext) {
+        for (Type t : vars) {
             UndetVar uv = (UndetVar)t;
             TypeVar ct = (TypeVar)uv.getInst();
-            ct.bound = types.glb(inferenceContext.asInstTypes(types.getBounds(ct)));
-            if (ct.bound.isErroneous()) {
+            ct.setUpperBound( types.glb(inferenceContext.asInstTypes(types.getBounds(ct))) );
+            if (ct.getUpperBound().isErroneous()) {
                 //report inference error if glb fails
                 reportBoundError(uv, InferenceBound.UPPER);
             }
-            formals = formals.tail;
         }
     }
 
@@ -557,37 +533,24 @@ public class Infer {
                                             List<Type> argtypes) {
         final Type restype;
 
-        if (spMethod == null || types.isSameType(spMethod.getReturnType(), syms.objectType)) {
-            // The return type of the polymorphic signature is polymorphic,
-            // and is computed from the enclosing tree E, as follows:
-            // if E is a cast, then use the target type of the cast expression
-            // as a return type; if E is an expression statement, the return
-            // type is 'void'; otherwise
-            // the return type is simply 'Object'. A correctness check ensures
-            // that env.next refers to the lexically enclosing environment in
-            // which the polymorphic signature call environment is nested.
+        Type spType = spMethod == null ? syms.objectType : spMethod.getReturnType();
 
-            switch (env.next.tree.getTag()) {
-                case TYPECAST:
-                    JCTypeCast castTree = (JCTypeCast)env.next.tree;
-                    restype = (TreeInfo.skipParens(castTree.expr) == env.tree) ?
-                              castTree.clazz.type :
-                              syms.objectType;
-                    break;
-                case EXEC:
-                    JCTree.JCExpressionStatement execTree =
-                            (JCTree.JCExpressionStatement)env.next.tree;
-                    restype = (TreeInfo.skipParens(execTree.expr) == env.tree) ?
-                              syms.voidType :
-                              syms.objectType;
-                    break;
-                default:
-                    restype = syms.objectType;
-            }
-        } else {
-            // The return type of the polymorphic signature is fixed
-            // (not polymorphic)
-            restype = spMethod.getReturnType();
+        switch (env.next.tree.getTag()) {
+            case TYPECAST:
+                JCTypeCast castTree = (JCTypeCast)env.next.tree;
+                restype = (TreeInfo.skipParens(castTree.expr) == env.tree) ?
+                          castTree.clazz.type :
+                          spType;
+                break;
+            case EXEC:
+                JCTree.JCExpressionStatement execTree =
+                        (JCTree.JCExpressionStatement)env.next.tree;
+                restype = (TreeInfo.skipParens(execTree.expr) == env.tree) ?
+                          syms.voidType :
+                          spType;
+                break;
+            default:
+                restype = spType;
         }
 
         List<Type> paramtypes = argtypes.map(new ImplicitArgType(spMethod, resolveContext.step));
@@ -628,7 +591,7 @@ public class Infer {
     TypeMapping<Void> fromTypeVarFun = new StructuralTypeMapping<Void>() {
         @Override
         public Type visitTypeVar(TypeVar tv, Void aVoid) {
-            UndetVar uv = new UndetVar(tv, incorporationEngine(), types);
+            UndetVar uv = new UndetVar(tv, incorporationEngine, types);
             if ((tv.tsym.flags() & Flags.THROWS) != 0) {
                 uv.setThrow();
             }
@@ -690,6 +653,122 @@ public class Infer {
             return owntype;
         }
     }
+
+    /**
+     * Infer record type for pattern matching. Given an expression type
+     * (@code expressionType}), and a given record ({@code patternTypeSymbol}),
+     * a parameterized type of {@code patternTypeSymbol} is inferred
+     * according to JLS 18.5.5.
+     *
+     * @param expressionType
+     * @param patternTypeSymbol
+     * @return
+     */
+    public Type instantiatePatternType(Type expressionType, TypeSymbol patternTypeSymbol) {
+        if (expressionType.tsym == patternTypeSymbol)
+            return expressionType;
+
+        //step 1:
+        List<Type> expressionTypes = List.nil();
+        List<Type> params = patternTypeSymbol.type.allparams();
+        List<Type> capturedWildcards = List.nil();
+        List<Type> todo = List.of(expressionType);
+        while (todo.nonEmpty()) {
+            Type current = todo.head;
+            todo = todo.tail;
+            switch (current.getTag()) {
+                case CLASS -> {
+                    if (current.isCompound()) {
+                        todo = todo.prependList(types.directSupertypes(current));
+                    } else {
+                        Type captured = types.capture(current);
+
+                        for (Type ta : captured.getTypeArguments()) {
+                            if (ta.hasTag(TYPEVAR) && ((TypeVar) ta).isCaptured()) {
+                                params = params.prepend((TypeVar) ta);
+                                capturedWildcards = capturedWildcards.prepend(ta);
+                            }
+                        }
+                        expressionTypes = expressionTypes.prepend(captured);
+                    }
+                }
+                case TYPEVAR -> {
+                    todo = todo.prepend(types.skipTypeVars(current, false));
+                }
+                default -> expressionTypes = expressionTypes.prepend(current);
+            }
+        }
+        //add synthetic captured ivars
+        InferenceContext c = new InferenceContext(this, params);
+        Type patternType = c.asUndetVar(patternTypeSymbol.type);
+        List<Type> exprTypes = expressionTypes.map(t -> c.asUndetVar(t));
+
+        capturedWildcards.forEach(s -> ((UndetVar) c.asUndetVar(s)).setNormal());
+
+        try {
+            //step 2:
+            for (Type exprType : exprTypes) {
+                if (exprType.isParameterized()) {
+                    Type patternAsExpression =
+                            types.asSuper(patternType, exprType.tsym);
+                    if (patternAsExpression == null ||
+                        !types.isSameType(patternAsExpression, exprType)) {
+                        return null;
+                    }
+                }
+            }
+
+            doIncorporation(c, types.noWarnings);
+
+            //step 3:
+            List<Type> freshVars = instantiatePatternVars(params, c);
+
+            Type substituted = c.asInstType(patternTypeSymbol.type);
+
+            //step 4:
+            return types.upward(substituted, freshVars);
+        } catch (Infer.InferenceException ex) {
+            return null;
+        }
+    }
+
+    private List<Type> instantiatePatternVars(List<Type> vars, InferenceContext c) {
+        ListBuffer<Type> freshVars = new ListBuffer<>();
+        ListBuffer<Type> todo = new ListBuffer<>();
+
+        //step 1 - create fresh tvars
+        for (Type t : vars) {
+            UndetVar undet = (UndetVar) c.asUndetVar(t);
+            List<Type> bounds = InferenceStep.EQ.filterBounds(undet, c);
+            if (bounds.nonEmpty()) {
+                undet.setInst(bounds.head);
+            } else {
+                List<Type> upperBounds = undet.getBounds(InferenceBound.UPPER);
+                Type upper;
+                boolean recursive = Type.containsAny(upperBounds, vars);
+                if (recursive) {
+                    upper = types.makeIntersectionType(upperBounds);
+                    todo.append(undet);
+                } else if (upperBounds.nonEmpty()) {
+                    upper = types.glb(upperBounds);
+                } else {
+                    upper = syms.objectType;
+                }
+                List<Type> lowerBounds = undet.getBounds(InferenceBound.LOWER);
+                Type lower = lowerBounds.isEmpty() ? syms.botType
+                                                   : lowerBounds.tail.isEmpty() ? lowerBounds.head
+                                                                                : types.lub(lowerBounds);
+                TypeVar vt = new TypeVar(syms.noSymbol, upper, lower);
+                freshVars.add(vt);
+                undet.setInst(vt);
+            }
+        }
+
+        //step 2 - replace fresh tvars in their bounds
+        replaceTypeVarsInBounds(todo.toList(), c);
+
+        return freshVars.toList();
+    }
     // </editor-fold>
 
     // <editor-fold defaultstate="collapsed" desc="Incorporation">
@@ -819,28 +898,6 @@ public class Infer {
         }
     }
 
-    /**
-     * Custom check executed by the legacy incorporation engine. Newly added bounds are checked
-     * against existing eq bounds.
-     */
-    class EqCheckLegacy extends CheckBounds {
-        EqCheckLegacy(UndetVar uv, Type t, InferenceBound from) {
-            super(uv, t, InferenceContext::asInstType, InferenceContext::free, from);
-        }
-
-        @Override
-        public IncorporationAction dup(UndetVar that) {
-            return new EqCheckLegacy(that, t, from);
-        }
-
-        @Override
-        EnumSet<InferenceBound> boundsToCheck() {
-            return (from == InferenceBound.EQ) ?
-                            EnumSet.allOf(InferenceBound.class) :
-                            EnumSet.of(InferenceBound.EQ);
-        }
-    }
-
     /**
      * Check that the inferred type conforms to all bounds.
      */
@@ -1029,7 +1086,7 @@ public class Infer {
      * This class models an incorporation engine. The engine is responsible for listening to
      * changes in inference variables and register incorporation actions accordingly.
      */
-    abstract class AbstractIncorporationEngine implements UndetVarListener {
+    class IncorporationEngine implements UndetVarListener {
 
         @Override
         public void varInstantiated(UndetVar uv) {
@@ -1042,31 +1099,6 @@ public class Infer {
             uv.incorporationActions.addAll(getIncorporationActions(uv, ib, bound, update));
         }
 
-        abstract List<IncorporationAction> getIncorporationActions(UndetVar uv, InferenceBound ib, Type t, boolean update);
-    }
-
-    /**
-     * A legacy incorporation engine. Used for source <= 7.
-     */
-    AbstractIncorporationEngine legacyEngine = new AbstractIncorporationEngine() {
-
-        List<IncorporationAction> getIncorporationActions(UndetVar uv, InferenceBound ib, Type t, boolean update) {
-            ListBuffer<IncorporationAction> actions = new ListBuffer<>();
-            Type inst = uv.getInst();
-            if (inst != null) {
-                actions.add(new CheckInst(uv, ib));
-            }
-            actions.add(new EqCheckLegacy(uv, t, ib));
-            return actions.toList();
-        }
-    };
-
-    /**
-     * The standard incorporation engine. Used for source >= 8.
-     */
-    AbstractIncorporationEngine graphEngine = new AbstractIncorporationEngine() {
-
-        @Override
         List<IncorporationAction> getIncorporationActions(UndetVar uv, InferenceBound ib, Type t, boolean update) {
             ListBuffer<IncorporationAction> actions = new ListBuffer<>();
             Type inst = uv.getInst();
@@ -1087,15 +1119,10 @@ public class Infer {
 
             return actions.toList();
         }
-    };
-
-    /**
-     * Get the incorporation engine to be used in this compilation.
-     */
-    AbstractIncorporationEngine incorporationEngine() {
-        return allowGraphInference ? graphEngine : legacyEngine;
     }
 
+    IncorporationEngine incorporationEngine = new IncorporationEngine();
+
     /** max number of incorporation rounds. */
     static final int MAX_INCORPORATION_STEPS = 10000;
 
@@ -1133,7 +1160,7 @@ public class Infer {
      * t = java.util.ArrayList<java.lang.String>
      * s = java.util.List<T>
      *
-     * we get this ouput (singleton list):
+     * we get this output (singleton list):
      *
      * [Pair[java.util.List<java.lang.String>,java.util.List<T>]]
      */
@@ -1214,14 +1241,10 @@ public class Infer {
 
         @Override
         public boolean equals(Object o) {
-            if (!(o instanceof IncorporationBinaryOp)) {
-                return false;
-            } else {
-                IncorporationBinaryOp that = (IncorporationBinaryOp)o;
-                return opKind == that.opKind &&
-                        types.isSameType(op1, that.op1) &&
-                        types.isSameType(op2, that.op2);
-            }
+            return (o instanceof IncorporationBinaryOp incorporationBinaryOp)
+                    && opKind == incorporationBinaryOp.opKind
+                    && types.isSameType(op1, incorporationBinaryOp.op1)
+                    && types.isSameType(op2, incorporationBinaryOp.op2);
         }
 
         @Override
@@ -1240,9 +1263,9 @@ public class Infer {
     }
 
     /** an incorporation cache keeps track of all executed incorporation-related operations */
-    Map<IncorporationBinaryOp, Boolean> incorporationCache = new HashMap<>();
+    Map<IncorporationBinaryOp, Boolean> incorporationCache = new LinkedHashMap<>();
 
-    protected static class BoundFilter implements Filter<Type> {
+    protected static class BoundFilter implements Predicate<Type> {
 
         InferenceContext inferenceContext;
 
@@ -1251,7 +1274,7 @@ public class Infer {
         }
 
         @Override
-        public boolean accepts(Type t) {
+        public boolean test(Type t) {
             return !t.isErroneous() && !inferenceContext.free(t) &&
                     !t.hasTag(BOT);
         }
@@ -1321,11 +1344,17 @@ public class Infer {
         public static class NodeNotFoundException extends RuntimeException {
             private static final long serialVersionUID = 0;
 
-            InferenceGraph graph;
+            transient InferenceGraph graph;
 
             public NodeNotFoundException(InferenceGraph graph) {
                 this.graph = graph;
             }
+
+            @Override
+            public Throwable fillInStackTrace() {
+                // This is an internal exception; the stack trace is irrelevant.
+                return this;
+            }
         }
         /**
          * Pick the next node (leaf) to solve in the graph
@@ -1366,7 +1395,7 @@ public class Infer {
         }
 
         /**
-         * Computes a path that goes from a given node to the leafs in the graph.
+         * Computes a path that goes from a given node to the leaves in the graph.
          * Typically this will start from a node containing a variable in
          * {@code varsToSolve}. For any given path, the cost is computed as the total
          * number of type-variables that should be eagerly instantiated across that path.
@@ -1396,7 +1425,7 @@ public class Infer {
         }
 
         /** cache used to avoid redundant computation of tree costs */
-        final Map<Node, Pair<List<Node>, Integer>> treeCache = new HashMap<>();
+        final Map<Node, Pair<List<Node>, Integer>> treeCache = new LinkedHashMap<>();
 
         /** constant value used to mark non-existent paths */
         final Pair<List<Node>, Integer> noPath = new Pair<>(null, Integer.MAX_VALUE);
@@ -1503,21 +1532,6 @@ public class Infer {
                 }
             }
         },
-        /**
-         * Like the former; the only difference is that this step can only be applied
-         * if all upper bounds are ground.
-         */
-        UPPER_LEGACY(InferenceBound.UPPER) {
-            @Override
-            public boolean accepts(UndetVar t, InferenceContext inferenceContext) {
-                return !inferenceContext.free(t.getBounds(ib)) && !t.isCaptured();
-            }
-
-            @Override
-            Type solve(UndetVar uv, InferenceContext inferenceContext) {
-                return UPPER.solve(uv, inferenceContext);
-            }
-        },
         /**
          * Like the former; the only difference is that this step can only be applied
          * if all upper/lower bounds are ground.
@@ -1571,23 +1585,6 @@ public class Infer {
         }
     }
 
-    /**
-     * This enumeration defines the sequence of steps to be applied when the
-     * solver works in legacy mode. The steps in this enumeration reflect
-     * the behavior of old inference routine (see JLS SE 7 15.12.2.7/15.12.2.8).
-     */
-    enum LegacyInferenceSteps {
-
-        EQ_LOWER(EnumSet.of(InferenceStep.EQ, InferenceStep.LOWER)),
-        EQ_UPPER(EnumSet.of(InferenceStep.EQ, InferenceStep.UPPER_LEGACY));
-
-        final EnumSet<InferenceStep> steps;
-
-        LegacyInferenceSteps(EnumSet<InferenceStep> steps) {
-            this.steps = steps;
-        }
-    }
-
     /**
      * This enumeration defines the sequence of steps to be applied when the
      * graph solver is used. This order is defined so as to maximize compatibility
@@ -1621,10 +1618,10 @@ public class Infer {
         /** stuck dependency */
         STUCK("dashed");
 
-        final String dotSyle;
+        final String dotStyle;
 
-        private DependencyKind(String dotSyle) {
-            this.dotSyle = dotSyle;
+        private DependencyKind(String dotStyle) {
+            this.dotStyle = dotStyle;
         }
     }
 
@@ -1756,7 +1753,7 @@ public class Infer {
                  * through all its dependencies.
                  */
                 protected Set<Node> closure() {
-                    Set<Node> closure = new HashSet<>();
+                    Set<Node> closure = new LinkedHashSet<>();
                     closureInternal(closure);
                     return closure;
                 }
@@ -1829,7 +1826,7 @@ public class Infer {
                 @Override
                 public Properties dependencyAttributes(Node sink, GraphUtils.DependencyKind dk) {
                     Properties p = new Properties();
-                    p.put("style", ((DependencyKind)dk).dotSyle);
+                    p.put("style", ((DependencyKind)dk).dotStyle);
                     StringBuilder buf = new StringBuilder();
                     String sep = "";
                     for (Type from : data) {
