@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "19.0.2";
+        "20.0.1";
 
     private static final String java_version_date =
-        "2023-01-17";
+        "2023-04-18";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "19.0.2+7";
+        "20.0.1+9";
 
     private static final String VERSION_NUMBER =
-        "19.0.2";
+        "20.0.1";
 
     private static final String VERSION_SPECIFICATION =
-        "19";
+        "20";
 
     private static final String VERSION_BUILD =
-        "7";
+        "9";
 
     private static final String VERSION_PRE =
         "";
@@ -70,13 +70,13 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "63.0";
+        "64.0";
 
     private static final String VENDOR =
         "N/A";
 
     private static final String VENDOR_URL =
-        "https://openjdk.java.net/";
+        "https://openjdk.org/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
@@ -186,25 +186,13 @@ class VersionProps {
         }
     }
 
-    /**
-     * In case you were wondering this method is called by java -version.
-     */
-    public static void print(boolean err) {
-        print(err, false);
-    }
 
-    /**
-     * This is the same as print except that it adds an extra line-feed
-     * at the end, typically used by the -showversion in the launcher
-     */
-    public static void println(boolean err) {
-        print(err, true);
-    }
 
     /**
      * Print version info.
+     * In case you were wondering this method is called by java -version.
      */
-    private static void print(boolean err, boolean newln) {
+    private static void print(boolean err) {
         PrintStream ps = err ? System.err : System.out;
 
         /* First line: platform version. */
