@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -99,6 +99,12 @@ import sun.util.locale.provider.LocaleServiceProviderPool;
  * and a diacritical mark. What users consider to be a character can
  * differ between languages.
  *
+ * @implSpec The default implementation of the character boundary analysis
+ * conforms to the Unicode Consortium's Extended Grapheme Cluster breaks.
+ * For more detail, refer to
+ * <a href="https://www.unicode.org/reports/tr29/#Grapheme_Cluster_Boundaries">
+ * Grapheme Cluster Boundaries</a> section in the Unicode Standard Annex #29.
+ *
  * <p>
  * The {@code BreakIterator} instances returned by the factory methods
  * of this class are intended for use with natural languages only, not for
@@ -318,7 +324,7 @@ public abstract class BreakIterator implements Cloneable
 
     /**
      * Returns the first boundary following the specified character offset. If the
-     * specified offset equals to the last text boundary, it returns
+     * specified offset is equal to the last text boundary, it returns
      * {@code BreakIterator.DONE} and the iterator's current position is unchanged.
      * Otherwise, the iterator's current position is set to the returned boundary.
      * The value returned is always greater than the offset or the value
@@ -334,7 +340,7 @@ public abstract class BreakIterator implements Cloneable
 
     /**
      * Returns the last boundary preceding the specified character offset. If the
-     * specified offset equals to the first text boundary, it returns
+     * specified offset is equal to the first text boundary, it returns
      * {@code BreakIterator.DONE} and the iterator's current position is unchanged.
      * Otherwise, the iterator's current position is set to the returned boundary.
      * The value returned is always less than the offset or the value
@@ -560,22 +566,13 @@ public abstract class BreakIterator implements Cloneable
 
     private static BreakIterator createBreakInstance(LocaleProviderAdapter adapter, Locale locale, int type) {
         BreakIteratorProvider breakIteratorProvider = adapter.getBreakIteratorProvider();
-        BreakIterator iterator = null;
-        switch (type) {
-        case CHARACTER_INDEX:
-            iterator = breakIteratorProvider.getCharacterInstance(locale);
-            break;
-        case WORD_INDEX:
-            iterator = breakIteratorProvider.getWordInstance(locale);
-            break;
-        case LINE_INDEX:
-            iterator = breakIteratorProvider.getLineInstance(locale);
-            break;
-        case SENTENCE_INDEX:
-            iterator = breakIteratorProvider.getSentenceInstance(locale);
-            break;
-        }
-        return iterator;
+        return switch (type) {
+            case CHARACTER_INDEX -> breakIteratorProvider.getCharacterInstance(locale);
+            case WORD_INDEX      -> breakIteratorProvider.getWordInstance(locale);
+            case LINE_INDEX      -> breakIteratorProvider.getLineInstance(locale);
+            case SENTENCE_INDEX  -> breakIteratorProvider.getSentenceInstance(locale);
+            default              -> null;
+        };
     }
 
     /**
@@ -585,8 +582,9 @@ public abstract class BreakIterator implements Cloneable
      * The returned array represents the union of locales supported by the Java
      * runtime and by installed
      * {@link java.text.spi.BreakIteratorProvider BreakIteratorProvider} implementations.
-     * It must contain at least a {@code Locale}
-     * instance equal to {@link java.util.Locale#US Locale.US}.
+     * At a minimum, the returned array must contain a {@code Locale} instance equal to
+     * {@link Locale#ROOT Locale.ROOT} and a {@code Locale} instance equal to
+     * {@link Locale#US Locale.US}.
      *
      * @return An array of locales for which localized
      *         {@code BreakIterator} instances are available.
