@@ -130,7 +130,7 @@ public class CurrencyNames_is extends OpenListResourceBundle {
             { "INR", "INR" },
             { "IQD", "IQD" },
             { "IRR", "IRR" },
-            { "ISK", "ISK" },
+            { "ISK", "kr." },
             { "JMD", "JMD" },
             { "JOD", "JOD" },
             { "KES", "KES" },
@@ -284,7 +284,7 @@ public class CurrencyNames_is extends OpenListResourceBundle {
             { "etb", "e\u00fe\u00ed\u00f3p\u00edskt birr" },
             { "eur", "evra" },
             { "fim", "Finnskt mark" },
-            { "fjd", "fidjeyskur dalur" },
+            { "fjd", "f\u00eddj\u00edskur dalur" },
             { "fkp", "falklenskt pund" },
             { "frf", "Franskur franki" },
             { "gbp", "sterlingspund" },
@@ -409,7 +409,7 @@ public class CurrencyNames_is extends OpenListResourceBundle {
             { "tjs", "tadsjikskur s\u00f3m\u00f3ni" },
             { "tmm", "T\u00farkmenskt manat (1993\u20132009)" },
             { "tmt", "t\u00farkmenskt manat" },
-            { "tnd", "t\u00fan\u00edskur denari" },
+            { "tnd", "t\u00faniskur denari" },
             { "top", "Tongapanga" },
             { "tpe", "T\u00edmorskur sk\u00fati" },
             { "trl", "Tyrknesk l\u00edra (1922\u20132005)" },
