@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -97,7 +93,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Cuba = new String[] {
                "Standard na Oras sa Cuba",
                "",
-               "Daylight Time sa Cuba",
+               "Daylight na Oras sa Cuba",
                "",
                "Oras sa Cuba",
                "",
@@ -207,7 +203,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
             };
         final String[] India = new String[] {
-               "Standard na Oras sa Bhutan",
+               "Standard na Oras sa India",
                "",
                "",
                "",
@@ -278,6 +274,14 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "Oras sa Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Oras sa Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Standard na Oras sa Alaska",
                "",
@@ -519,7 +523,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
-               "Standard na Norfolk Island",
+               "Standard na Oras sa Norfolk Island",
                "",
                "Daylight Time sa Norfolk Island",
                "",
@@ -593,7 +597,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Atlantic = new String[] {
                "Standard na Oras sa Atlantiko",
                "",
-               "Daylight Time sa Atlantiko",
+               "Daylight na Oras sa Atlantiko",
                "",
                "Oras sa Atlantiko",
                "",
@@ -758,14 +762,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "Oras sa Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Oras sa Macquarie Island",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Oras sa Marquesas",
                "",
@@ -929,7 +925,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Newfoundland = new String[] {
                "Standard na Oras sa Newfoundland",
                "",
-               "Daylight Time sa Newfoundland",
+               "Daylight na Oras sa Newfoundland",
                "",
                "Oras sa Newfoundland",
                "",
@@ -1033,7 +1029,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Mexico_Pacific = new String[] {
                "Standard na Oras sa Pasipiko ng Mexico",
                "",
-               "Daylight Time sa Pasipiko ng Mexico",
+               "Daylight na Oras sa Pasipiko ng Mexico",
                "",
                "Oras sa Pasipiko ng Mexico",
                "",
@@ -1047,27 +1043,27 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Central = new String[] {
-               "Sentral na Karaniwang Oras",
+               "Sentral na Standard na Oras sa North America",
                "",
-               "Sentral na Daylight Time",
+               "Sentral na Daylight na Oras sa North America",
                "",
-               "Sentral na Oras",
+               "Sentral na Oras sa North America",
                "",
             };
         final String[] America_Eastern = new String[] {
-               "Eastern na Standard na Oras",
+               "Standard na Oras sa Silangan ng Hilangang Amerika",
                "",
-               "Eastern Daylight Time",
+               "Daylight na Oras sa Silangan ng Hilagang Amerika",
                "",
-               "Eastern Time",
+               "Oras sa Silangan ng Hilagang Amerika",
                "",
             };
         final String[] America_Pacific = new String[] {
-               "Standard na Oras sa Pasipiko",
+               "Standard na Oras sa Pasipiko sa Hilagang Amerika",
                "",
-               "Daylight Time sa Pasipiko",
+               "Daylight na Oras sa Pasipiko sa Hilagang Amerika",
                "",
-               "Oras sa Pasipiko",
+               "Oras sa Pasipiko sa HIlagang Amerika",
                "",
             };
         final String[] French_Southern = new String[] {
@@ -1105,17 +1101,17 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Pierre_Miquelon = new String[] {
                "Standard na Oras sa Saint Pierre & Miquelon",
                "",
-               "Daylight Time sa Saint Pierre & Miquelon",
+               "Daylight na Oras sa Saint Pierre & Miquelon",
                "",
                "Oras sa Saint Pierre & Miquelon",
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Standard na Oras sa Bundok",
+               "Standard na Oras sa Bundok sa Hilagang Amerika",
                "",
-               "Daylight Time sa Bundok",
+               "Daylight na Oras sa Bundok sa Hilagang Amerika",
                "",
-               "Oras sa Bundok",
+               "Oras sa Bundok sa Hilagang Amerika",
                "",
             };
         final String[] Marshall_Islands = new String[] {
@@ -1129,7 +1125,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Mexico_Northwest = new String[] {
                "Standard na Oras sa Hilagang-kanlurang Mexico",
                "",
-               "Daylight Time sa Hilagang-kanlurang Mexico",
+               "Daylight na Oras sa Hilagang-kanlurang Mexico",
                "",
                "Oras sa Hilagang-kanlurang Mexico",
                "",
@@ -1283,7 +1279,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1292,7 +1287,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1379,7 +1374,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1442,7 +1436,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1518,7 +1512,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1567,7 +1561,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1603,7 +1596,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1647,7 +1640,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,9 +1680,10 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
