@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u00c0m Chasey",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Bun-\u00e0m na Sile",
                "",
@@ -286,6 +290,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "\u00c0m Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Bun-\u00e0m Alaska",
                "AKST",
@@ -607,11 +619,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "AT",
             };
         final String[] Brasilia = new String[] {
-               "Bun-\u00e0m Bhrasilia",
+               "Bun-\u00e0m Bhras\u00edlia",
                "",
-               "T\u00ecde samhraidh Bhrasilia",
+               "T\u00ecde samhraidh Bhras\u00edlia",
                "",
-               "\u00c0m Bhrasilia",
+               "\u00c0m Bhras\u00edlia",
                "",
             };
         final String[] Chamorro = new String[] {
@@ -766,14 +778,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u00c0m Eilein MhicGuaire",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u00c0m Eileanan a\u2019 Mharcais",
                "",
@@ -1300,7 +1304,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1309,7 +1312,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1396,7 +1399,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1468,7 +1470,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1544,7 +1546,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1594,7 +1596,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1630,7 +1632,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1675,7 +1677,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1715,9 +1717,10 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1799,7 +1802,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Bahrain", "Bachrain" },
             { "timezone.excity.Asia/Bangkok", "Bangkok" },
             { "timezone.excity.Asia/Barnaul", "Barnaul" },
-            { "timezone.excity.Asia/Bishkek", "Bishkek" },
+            { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Asia/Irkutsk", "Irkutsk" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
@@ -1808,7 +1811,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Magadan", "Magadan" },
             { "timezone.excity.Asia/Nicosia", "Nicosia" },
             { "timezone.excity.Asia/Rangoon", "Rangun" },
-            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
+            { "timezone.excity.Asia/Tbilisi", "T\u2019bilisi" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
             { "timezone.excity.Asia/Yakutsk", "Yakutsk" },
             { "timezone.excity.Asia/Yerevan", "Yerevan" },
@@ -1847,14 +1850,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.Asia/Ashgabat", "A\u015fgabat" },
             { "timezone.excity.Asia/Damascus", "Damascus" },
-            { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
+            { "timezone.excity.Asia/Dushanbe", "Du\u0161anbe" },
             { "timezone.excity.Asia/Jayapura", "Jayapura" },
             { "timezone.excity.Asia/Khandyga", "Khandyga" },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "timezone.excity.Asia/Qostanay", "Qostana\u0131" },
             { "timezone.excity.Asia/Sakhalin", "Sakhalin" },
             { "timezone.excity.Asia/Shanghai", "Shanghai" },
-            { "timezone.excity.Asia/Tashkent", "Tashkent" },
+            { "timezone.excity.Asia/Tashkent", "To\u0161kent" },
             { "timezone.excity.Asia/Ust-Nera", "Ust-Nera" },
             { "timezone.excity.Europe/Athens", "An \u00c0ithne" },
             { "timezone.excity.Europe/Berlin", "Berlin" },
@@ -1889,7 +1892,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Belize", "A\u2019 Bheil\u00ecs" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Caimean" },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "timezone.excity.America/Dawson", "Dawson" },
@@ -1901,7 +1903,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/La_Paz", "La Paz" },
             { "timezone.excity.America/Maceio", "Macei\u00f3" },
             { "timezone.excity.America/Manaus", "Manaus" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.America/Nassau", "Nassau" },
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.America/Recife", "Recife" },
@@ -1924,6 +1925,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Rapa Nui" },
+            { "timezone.excity.Pacific/Kanton", "Kanton" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midway" },
@@ -2143,7 +2145,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Barthelemy", "Saint Barth\u00e9lemy" },
             { "timezone.excity.America/Swift_Current", "Swift Current" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
-            { "timezone.excity.America/Bahia_Banderas", "Bah\u00eda de Banderas" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "timezone.excity.Atlantic/South_Georgia", "Se\u00f2rsea a Deas" },
             { "timezone.excity.America/Argentina/Salta", "Salta" },
