@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -278,6 +274,14 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "Ora di Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Ora dello Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Ora standard dell\u2019Alaska",
                "",
@@ -758,14 +762,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "Ora di Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Ora dell\u2019Isola Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Ora delle Marchesi",
                "",
@@ -1283,7 +1279,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1292,7 +1287,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1379,7 +1374,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1442,7 +1436,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1518,7 +1512,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1567,7 +1561,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1603,7 +1596,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1647,7 +1640,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,9 +1680,10 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1858,7 +1852,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Belize", "Belize" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Cayman" },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "timezone.excity.America/Dawson", "Dawson" },
@@ -1870,9 +1863,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.America/La_Paz", "La Paz" },
             { "timezone.excity.America/Maceio", "Maceio" },
             { "timezone.excity.America/Manaus", "Manaus" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.America/Nassau", "Nassau" },
-            { "timezone.excity.America/Panama", "Panam\u00e1" },
             { "timezone.excity.America/Recife", "Recife" },
             { "timezone.excity.America/Regina", "Regina" },
             { "timezone.excity.Asia/Famagusta", "Famagosta" },
@@ -1893,6 +1884,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "La Riunione" },
             { "timezone.excity.Pacific/Easter", "Pasqua" },
+            { "timezone.excity.Pacific/Kanton", "Canton" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midway" },
@@ -1980,7 +1972,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Asia/Novosibirsk", "Novosibirsk" },
-            { "timezone.excity.Asia/Ulaanbaatar", "Ulaanbaatar" },
+            { "timezone.excity.Asia/Ulaanbaatar", "Ulan Bator" },
             { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
             { "timezone.excity.Atlantic/Madeira", "Madeira" },
@@ -1999,7 +1991,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Stockholm", "Stoccolma" },
             { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
-            { "timezone.excity.Indian/Christmas", "Natale" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
             { "timezone.excity.Indian/Mauritius", "Mauritius" },
             { "timezone.excity.Pacific/Auckland", "Auckland" },
@@ -2112,7 +2103,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Barthelemy", "Saint-Barth\u00e9lemy" },
             { "timezone.excity.America/Swift_Current", "Swift Current" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
-            { "timezone.excity.America/Bahia_Banderas", "Bah\u00eda de Banderas" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "timezone.excity.Atlantic/South_Georgia", "Georgia del Sud" },
             { "timezone.excity.America/Argentina/Salta", "Salta" },
